import * as lambda from 'aws-cdk-lib/aws-lambda';
/**
 * Only applicable to TokenProviderLambdaCodeOptions.
 * Ensure that the lambda function architecture matches.
 */
export declare class ApplicationArchitecture {
    readonly name: string;
    static readonly X86_64: ApplicationArchitecture;
    static readonly ARM_64: ApplicationArchitecture;
    private constructor();
}
/**
 * Use this to build a supported the TokenProvider lambda application when the source is located in a public repository.
 */
export interface TokenProviderLambdaCodeOptions {
    /**
     * Repository Url
     * Example: https://github.com/catnekaise/example-fork.git
     */
    readonly repository?: string;
    /**
     * Value for `git checkout` after cloning the repository
     * Example: main, origin/feature1, SHA
     */
    readonly checkout?: string;
    /**
     * Should be equal to the architecture configured for the lambda function. This value is used to build the application in the specified architecture.
     */
    readonly architecture?: ApplicationArchitecture;
    /**
     * Value for docker platform
     * Example: linux/amd64
     */
    readonly platform?: string;
}
export declare abstract class TokenProviderLambdaCode {
    static defaultGo(options?: TokenProviderLambdaCodeOptions): lambda.Code;
    static dotnet(options?: TokenProviderLambdaCodeOptions): lambda.Code;
    private static repoBuildArgs;
}
